;************************************************************************
Pro var_map_reader,file_name,pos,var,num
;
;    This procedure reads in the listing of model variability values
;    (standard deviations) across a high-latitude grid (where data is available)
;
;  INPUT:
;    file_name: name of file containing variability data
;
;    NOTE: the naming convention of the file names is as follows: 
;    - the 'omni' prefix indcates we used solar wind data from OMNI
;    - then 'north' or 'south' indicates the hemisphere
;    - the numbers 0.00t1.20, 1.20t1.70, etc. indicate the Esw magnitude bin in mV/m
;    - the string Bz+_By+ etc. indicates the IMF clock angle bin
;    - the string DP-,DP0,DP+ indicates negative neutral, or positive
;      tilt (for either hemispere, positive tilt is summer-like conditions)
;
;  RETURN VALUES:
;    pos:  This argument is a 2D array defining the locations of the model 
;          variability values in altidude adjusted geomagnetic coordinates (AACGM).
;      1st column: latitude in degrees
;      2nd column: longitude in degrees
;
;   var:   Array of model variability values (in m/s) at the locations specified
;
;   num:   Array of integers giving then number of LOS data points used in
;          calculating the stadard deviation at each location
;
;  AUTHOR: Ellen Pettigrew Cousins, Dartmouth College
;          Dec, 2010
;
;  EXAMPLE CALLING SEQUENCE:
;  var_map_reader,'omni.north_2.20t2.90_By-_DP-_var.dat',pos,var,num
;*************************************************************************
;

openr,dat_unit,file_name,/get_lun

readf,dat_unit,n_col,n_pix

data = fltarr(n_col,n_pix)
readf,dat_unit,data

pos = data[0:1,*]
var = reform(data[2,*])
num = reform(fix(data[3,*]))

close,dat_unit
free_lun,dat_unit

end
